@@ -11,7 +11,7 @@ from microt_prompt_matrix.utils.get_time_diff import *
 target_file_pattern_mims = 'watch_accelerometer_mims_clean*.csv'
 target_file_pattern_mims_minute = 'watch_accelerometer_mims_minute*.csv'
 target_file_pattern_swan_minute = 'watch_accelerometer_swan_minute*.csv'
-
+mims_cutoff_list = {"PA_Level1": 10.558, "PA_Level2": 15.047, "PA_Level3": 19.614, "PA_Level4": 25.0, "PA_Level5": 25.0}
 
 def validate_dates_before_after(intermediate_participant_path, date_in_study, target_file_pattern):
     validated_date_list = []
@@ -172,9 +172,15 @@ def get_mims_summary_after_prompt(sec_after, prompt_time, closest_times, df_logs
     return mims_summary, num_readings, start_time
 
 
-def get_mims_summary_after_prompt_wearstate(wear_state, sec_after, prompt_time, df_mims_swan_minute_combined, date_in_study):
+def get_mims_summary_after_prompt_wearstate(wear_state, sec_after, prompt_time, df_mims_swan_minute_combined,
+                                            date_in_study):
     mims_summary_wearstate = 0
     mims_wearstate_min = 0
+    pa_level1_min = 0
+    pa_level2_min = 0
+    pa_level3_min = 0
+    pa_level4_min = 0
+    pa_level5_min = 0
     max_idx = len(df_mims_swan_minute_combined) - 1
 
     window_start_idices = df_mims_swan_minute_combined[
@@ -187,7 +193,7 @@ def get_mims_summary_after_prompt_wearstate(wear_state, sec_after, prompt_time,
         window_end_idx = window_start_idx + min_num
         if window_end_idx > max_idx:
             window_end_idx = max_idx
-        for idx in range(window_start_idx, window_end_idx + 1):
+        for idx in range(window_start_idx+1, window_end_idx + 1):
             swan_pred = df_mims_swan_minute_combined.loc[idx, "SWAN_PREDICTION"]
             # print(swan_pred)
             if swan_pred != wear_state:
@@ -197,11 +203,25 @@ def get_mims_summary_after_prompt_wearstate(wear_state, sec_after, prompt_time,
                 mims_value = df_mims_swan_minute_combined.loc[idx, "MIMS_SUM"]
                 mims_summary_wearstate += mims_value
                 mims_wearstate_min += 1
+
+                if wear_state == "Wear":
+                    if mims_value < mims_cutoff_list["PA_Level1"]:
+                        pa_level1_min += 1
+                    elif mims_value >= mims_cutoff_list["PA_Level1"] and mims_value < mims_cutoff_list["PA_Level2"]:
+                        pa_level2_min += 1
+                    elif mims_value >= mims_cutoff_list["PA_Level2"] and mims_value < mims_cutoff_list["PA_Level3"]:
+                        pa_level3_min += 1
+                    elif mims_value >= mims_cutoff_list["PA_Level3"] and mims_value < mims_cutoff_list["PA_Level4"]:
+                        pa_level4_min += 1
+                    elif mims_value >= mims_cutoff_list["PA_Level4"]:
+                        pa_level5_min += 1
+                    else:
+                        pass
     else:
         mims_summary_wearstate = "NF"
         mims_wearstate_min = "NF"
 
-    return mims_summary_wearstate, mims_wearstate_min
+    return mims_summary_wearstate, mims_wearstate_min, pa_level1_min, pa_level2_min, pa_level3_min, pa_level4_min, pa_level5_min
 
 
 def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_minute_combined, date_in_study):
@@ -221,6 +241,12 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
     mims_summary_wearstate_after_list = []
     wearstate_min_after_list = []
 
+    pa_level1_wear_after_list = []
+    pa_level2_wear_after_list = []
+    pa_level3_wear_after_list = []
+    pa_level4_wear_after_list = []
+    pa_level5_wear_after_list = []
+
     for idx in prompt_local_datetime_series.index:
         # print(idx)
         matched_mims_summary_before_list = []
@@ -236,6 +262,11 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
 
         prompt_time = prompt_local_datetime_series[idx]
         # prompt_date = prompt_time.date()
+        matched_pa_level1_wear_min_after_list = []
+        matched_pa_level2_wear_min_after_list = []
+        matched_pa_level3_wear_min_after_list = []
+        matched_pa_level4_wear_min_after_list = []
+        matched_pa_level5_wear_min_after_list = []
 
         if df_mims_combined.shape[0] == 0:
             matched_mims_summary_before_list = [np.nan] * len(sec_before_list)
@@ -249,6 +280,12 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
             matched_mims_summary_wearstate_after_list = [np.nan] * len(sec_after_list)
             matched_wearstate_min_after_list = [np.nan] * len(sec_after_list)
 
+            matched_pa_level1_wear_min_after_list = [np.nan] * len(sec_after_list)
+            matched_pa_level2_wear_min_after_list = [np.nan] * len(sec_after_list)
+            matched_pa_level3_wear_min_after_list = [np.nan] * len(sec_after_list)
+            matched_pa_level4_wear_min_after_list = [np.nan] * len(sec_after_list)
+            matched_pa_level5_wear_min_after_list = [np.nan] * len(sec_after_list)
+
         else:
             subset_time_list = list(df_mims_combined["TIME_DATETIME"])
             pos = find_closest_time(prompt_time, subset_time_list)
@@ -282,13 +319,21 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
 
                 # mims summary and sample num of sleep, wear, nonwear
                 for wear_state in ["Wear", "Sleep", "Nonwear"]:
-                    mims_summary_wearstate, min_wearstate = get_mims_summary_after_prompt_wearstate(wear_state,
-                                                                                                    sec_after,
-                                                                                                    prompt_time,
-                                                                                                    df_mims_swan_minute_combined, date_in_study)
+                    mims_summary_wearstate, min_wearstate, pa_level1_min, pa_level2_min, pa_level3_min, pa_level4_min, pa_level5_min = get_mims_summary_after_prompt_wearstate(
+                        wear_state,
+                        sec_after,
+                        prompt_time,
+                        df_mims_swan_minute_combined, date_in_study)
 
                     matched_mims_summary_wearstate_after_list.append(mims_summary_wearstate)
                     matched_wearstate_min_after_list.append(min_wearstate)
+                    if wear_state == "Wear":
+                        matched_pa_level1_wear_min_after_list.append(pa_level1_min)
+                        matched_pa_level2_wear_min_after_list.append(pa_level2_min)
+                        matched_pa_level3_wear_min_after_list.append(pa_level3_min)
+                        matched_pa_level4_wear_min_after_list.append(pa_level4_min)
+                        matched_pa_level5_wear_min_after_list.append(pa_level5_min)
+
 
                 matched_mims_summary_after_list.append(mims_summary)
                 matched_window_readings_after_list.append(readings)
@@ -305,6 +350,13 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
         mims_summary_wearstate_after_list.append(matched_mims_summary_wearstate_after_list)
         wearstate_min_after_list.append(matched_wearstate_min_after_list)
 
+        pa_level1_wear_after_list.append(matched_pa_level1_wear_min_after_list)
+        pa_level2_wear_after_list.append(matched_pa_level2_wear_min_after_list)
+        pa_level3_wear_after_list.append(matched_pa_level3_wear_min_after_list)
+        pa_level4_wear_after_list.append(matched_pa_level4_wear_min_after_list)
+        pa_level5_wear_after_list.append(matched_pa_level5_wear_min_after_list)
+
+
     mims_summary_before_df = pd.DataFrame(list(map(np.ravel, mims_summary_before_list)))
     window_readings_before_df = pd.DataFrame(list(map(np.ravel, window_readings_before_list)))
     window_start_time_before_df = pd.DataFrame(list(map(np.ravel, window_start_time_before_list)))
@@ -316,6 +368,12 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
     mims_summary_wearstate_after_df = pd.DataFrame(list(map(np.ravel, mims_summary_wearstate_after_list)))
     wearstate_min_after_df = pd.DataFrame(list(map(np.ravel, wearstate_min_after_list)))
 
+    pa_level1_wear_after_df = pd.DataFrame(list(map(np.ravel, pa_level1_wear_after_list)))
+    pa_level2_wear_after_df = pd.DataFrame(list(map(np.ravel, pa_level2_wear_after_list)))
+    pa_level3_wear_after_df = pd.DataFrame(list(map(np.ravel, pa_level3_wear_after_list)))
+    pa_level4_wear_after_df = pd.DataFrame(list(map(np.ravel, pa_level4_wear_after_list)))
+    pa_level5_wear_after_df = pd.DataFrame(list(map(np.ravel, pa_level5_wear_after_list)))
+
     df = pd.DataFrame()
     for sec_before in sec_before_list:
         col = int(sec_before // 60 - 1)
@@ -365,6 +423,22 @@ def match_feature(prompt_local_datetime_series, df_mims_combined, df_mims_swan_m
             [df, wearstate_min_after_df[col * 3 + 2].rename("MIMS_NONWEAR_MIN_" + str(sec_after // 60) + "MIN_AFTER")],
             axis=1)
 
+        # activity level (sedentary/light/moderate/vigorous) during wear time
+        df = pd.concat([df, pa_level1_wear_after_df[col].rename("SEDENTARY_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")],
+                       axis=1)
+        df = pd.concat(
+            [df, pa_level2_wear_after_df[col].rename("LIGHT_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")],
+            axis=1)
+        df = pd.concat(
+            [df, pa_level3_wear_after_df[col].rename("MODERATE_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")],
+            axis=1)
+        df = pd.concat(
+            [df, pa_level4_wear_after_df[col].rename("VIGOROUS_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")],
+            axis=1)
+        df = pd.concat(
+            [df, pa_level5_wear_after_df[col].rename("VIGOROUS_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")],
+            axis=1)
+
     return df
 
 
@@ -391,7 +465,6 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
             column_names.append("WINDOW_STARTTIME_" + str(sec_before // 60) + "MIN_BEFORE")
             array_count += 3
 
-
         for sec_after in sec_after_list:
             column_names.append("MIMS_SUMMARY_" + str(sec_after // 60) + "MIN_AFTER")
             column_names.append("WINDOW_NUM_READINGS_" + str(sec_after // 60) + "MIN_AFTER")
@@ -405,9 +478,16 @@ def create_column(prompt_local_datetime_series, intermediate_participant_path, d
 
             column_names.append("MIMS_SUMMARY_NONWEAR_" + str(sec_after // 60) + "MIN_AFTER")
             column_names.append("MIMS_NONWEAR_MIN_" + str(sec_after // 60) + "MIN_AFTER")
-            array_count += 9
 
-        df = pd.DataFrame([[np.nan] * len(prompt_local_datetime_series)]*array_count).T
+            column_names.append("PA_LEVEL1_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")
+            column_names.append("PA_LEVEL2_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")
+            column_names.append("PA_LEVEL3_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")
+            column_names.append("PA_LEVEL4_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")
+            column_names.append("PA_LEVEL5_MIN_WEAR_" + str(sec_after // 60) + "MIN_AFTER")
+
+            array_count += 14
+
+        df = pd.DataFrame([[np.nan] * len(prompt_local_datetime_series)] * array_count).T
         df.columns = column_names
         return df
 
